@@ -2,7 +2,7 @@ package DBIx::QuickDB::Driver;
 use strict;
 use warnings;
 
-our $VERSION = '0.000006';
+our $VERSION = '0.000007';
 
 use Carp qw/croak confess/;
 use File::Path qw/remove_tree/;
@@ -168,7 +168,7 @@ sub connect {
     my $self = shift;
     my ($db_name, %params) = @_;
 
-    %params = (AutoCommit => 1) unless @_ > 1;
+    %params = (AutoCommit => 1, RaiseError => 1) unless @_ > 1;
 
     my $dbh;
     $self->do_in_env(
